@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use base qw<Tie::Handle>;
 use Symbol qw<geniosym>;
@@ -13,7 +13,7 @@ sub TIEHANDLE { return bless geniosym, __PACKAGE__ }
 
 sub PRINT {
     shift;
-    undef $\;
+    local $\ = undef;
 
     foreach my $str (@_) {
         my $copy = $str;
